@@ -7,22 +7,29 @@ use Wx::Event qw(EVT_PAINT);
 
 use Acme::Colour::Fuzzy;
 
-my( $r, $g, $b ) = @ARGV;
+my( $r, $g, $b, $pack ) = @ARGV;
 unless( defined( $r ) && defined( $g ) && defined( $b ) ) {
     print <<EOT;
-Usage: $0 <r> <g> <b>
+Usage: $0 <r> <g> <b> [<package>]
 
 e.g.: $0 255 128 128
+      $0 255 128 128 Color::Similarity::RGB
 EOT
     exit 0;
 }
 
-my $fuzzy = Acme::Colour::Fuzzy->new( 'VACCC' );
+$pack ||= 'Color::Similarity::HCL';
+
+eval "require $pack" or die $@;
+
+my $fuzzy = Acme::Colour::Fuzzy->new( 'VACCC', $pack );
 my $res = [ $fuzzy->colour_approximations( $r, $g, $b ) ];
 my $name = $fuzzy->colour_name( $r, $g, $b );
 
+( my $pp_pack = $pack ) =~ s/^Color::Similarity:://;
 my $app = Wx::SimpleApp->new;
-my $frame = Wx::Frame->new( undef, -1, '', [-1, -1], [300, 440] );
+my $frame = Wx::Frame->new( undef, -1, "($r, $g, $b) $pp_pack",
+                            [-1, -1], [300, 440] );
 my $y = 0;
 for my $row ( { distance => 0,
                 name     => 'ORIGINAL: ' . $name,
@@ -45,3 +52,30 @@ $app->MainLoop;
 
 exit 0;
 
+=pod
+
+package Graphics::ColorNames::My;
+
+BEGIN { $INC{'Graphics/ColorNames/My.pm'} = __FILE__ }
+
+use constant STEP => 15;
+
+my %colors;
+
+sub NamesRgbTable() {
+    use integer;
+
+    return \%colors if %colors;
+
+    for( my $r = 0; $r < 256; $r += STEP ) {
+        for( my $g = 0; $g < 256; $g += STEP ) {
+            for( my $b = 0; $b < 256; $b += STEP ) {
+                $colors{"($r, $g, $b)"} = ( $r << 16 ) + ( $g << 8 ) + $b;
+            }
+        }
+    }
+
+    return \%colors;
+}
+
+=cut
